"use strict";
"use client";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSessionStorage = exports.useLocalStorage = void 0;
var tslib_1 = require("tslib");
var react_1 = require("react");
var window_1 = tslib_1.__importDefault(require("../../util/window"));
var useDebounce_1 = tslib_1.__importDefault(require("../useDebounce"));
var useInterval_1 = tslib_1.__importDefault(require("../useInterval"));
function useStorage(key, defaultValue, storage) {
    var storageObject = (0, react_1.useMemo)(function () { return window_1.default === null || window_1.default === void 0 ? void 0 : window_1.default[storage]; }, []);
    var fetcher = (0, react_1.useCallback)(function () {
        var jsonValue = storageObject === null || storageObject === void 0 ? void 0 : storageObject.getItem(key);
        try {
            if (jsonValue !== null)
                return JSON.parse(jsonValue !== null && jsonValue !== void 0 ? jsonValue : "{}");
        }
        catch (e) {
        }
        finally {
            if (typeof defaultValue === "function") {
                return defaultValue();
            }
            else {
                return defaultValue;
            }
        }
    }, []);
    var _a = (0, react_1.useState)(function () { return fetcher(); }), value = _a[0], setValue = _a[1];
    var _b = (0, react_1.useState)(value), passValue = _b[0], setPassValue = _b[1];
    (0, useDebounce_1.default)(function () {
        if (value === undefined) {
            storageObject === null || storageObject === void 0 ? void 0 : storageObject.removeItem(key);
        }
        else {
            storageObject === null || storageObject === void 0 ? void 0 : storageObject.setItem(key, JSON.stringify(value));
        }
        setPassValue(value);
    }, 100, [key, value, storageObject]);
    (0, useInterval_1.default)(function () {
        if (!storageObject)
            return;
        setValue(function () { return fetcher(); });
    }, 100);
    var remove = (0, react_1.useCallback)(function () {
        setValue(undefined);
    }, []);
    return [passValue, setValue, remove];
}
exports.default = useStorage;
function useLocalStorage(key, defaultValue) {
    return useStorage(key, defaultValue, "localStorage");
}
exports.useLocalStorage = useLocalStorage;
function useSessionStorage(key, defaultValue) {
    return useStorage(key, defaultValue, "sessionStorage");
}
exports.useSessionStorage = useSessionStorage;
